**L's Voice Training Guide**

# Introduction

Hey, friend. Want to change your voice? Well... you _can_ \- that's an option.

Your voice is much more malleable than you may realize. There are at least a dozen different dimensions that you can learn to control independently to change the sound of your voice. The way you talk right now is not your one "true" voice, it is a _habit_. A habit that can be changed, if you so choose.

I like to come at this challenge from two angles. One is to break down all the muscle movements involved and learn to manipulate them individually, through simple _drills_. The other is to listen to carefully selected example voices and learn to _imitate_ them, intuitively. You will get results much faster by using both, as you do in this guide.

My approach to voice training is not a process of feminization. It is a journey in flexibility, to full _fluency_ over the entire possibility space of your voice. This guide is aimed at those of you who are already comfortable in the masculine end of the spectrum. With the exercises I've gathered here, you will familiarize yourself with the feminine end - and everything in between.

Once you have gained complete freedom across your vocal range, you can _choose_ exactly where you'd like to live - whether that is within one voice, or two. Or three. Masculine, feminine, or androgynous, young or old, human or cartoon. Any or all. It's up to you.

So now, **listen to [this clip](https://clyp.it/5eq3io3u)** to hear me demonstrate the eight most important elements for vocal feminization, gradually transforming a masculine voice into a feminine one. Then, **listen to [this clip](https://clyp.it/ggetrab2)** to hear how they sound one at a time, in isolation. With practice, you can learn to do this too!

Most of the material in this guide can be traced back to the pioneering work of [Zheanna Erose](https://www.youtube.com/c/ZheannaErose) of [TransVoiceLessons](https://www.youtube.com/channel/UCBYlEnfAUbrYSwF0VujcmHA), as well as the excellent free tutorial videos at [New York Vocal Coaching](https://www.youtube.com/user/NewYorkVocalCoaching). Many thanks, also, to the [Scinguistics](https://cramdvoicelessons.blog/about/) community, and of course, all of you lovely people here on [r/transvoice](/r/transvoice)!

I've organized this guide into four levels, from Foundations to Mastery, each split into three subsections. You could easily spend a month on each level - a week or two per subsection. But you don't have to master each subsection before moving on to the next. Just give yourself enough time to digest the material and get a feel for it, and then start the next subsection as soon as you no longer feel overwhelmed.

Ready? Let's begin.

~L

# Level 1 - Foundations

## 1\. Inspiration

Start by watching [this video](https://youtu.be/dZKzuVfUv3E) for a really quick overview of the voice feminization process (and optionally, [this video](https://youtu.be/ynFqjE2AEGk) to learn more about the acoustic theory involved). Then watch [this video](https://youtu.be/xVAVi11kzbM?t=133) for a breakdown of the vocal anatomy involved.

**Your homework is** to find a recording of a female speaking voice that you'd like to be able to imitate, that can serve as an _inspiration_ and a point of reference. It doesn't have to be the one perfect, ultimate voice - just find one or two examples that seem pleasant and relatable. Think of female actresses or characters with nice voices, or YouTubers or podcast hosts you enjoy (search for "female youtubers" or "female podcast hosts" if you need some ideas). Mine is [this podcast interview with Keon Saghari](https://drive.google.com/open?id=1pIUvhv59np_tDRK7w0s75IQ3ByIoG6bs). Go ahead and use that if you can't decide on one right now!

Then start listening to it, at least a little bit every day. This will help you internalize the sounds and speech patterns of the voice that you like. And be on the lookout for new voices - if you find one you like better, start listening to that one instead!

## 2\. Vocal Tract Length

Next you want to start strengthening and learning to control the muscles that raise your _larynx_ (or voice box). This is how you shorten the _length of your vocal tract_, from your larynx to your lips, to match the proportions of a typical female vocal tract. Building these muscles will take a while, so we'll start with this first.

Watch [this video](https://youtu.be/aWWevU4A5mU) and try the _swallow-and-hold_ exercise. You want to touch your larynx (Adam's apple) lightly with your finger, and then yawn and feel it move down, and then swallow and feel it move up.

Once you have felt this a few times, watch [this video](https://youtu.be/mx4dPWKVt9o) and try the _"big dog, small dog"_ exercise. If you're having trouble with the small dog, it can help to start yawning, to bring the larynx down, and then start to swallow to bring the larynx up, and then stick your tongue out like a dog panting and say "ahh" in a whisper to make sure you're not closing off your throat. Then watch [this video](https://youtu.be/F6Noi2qERus) and try the _whisper siren_ exercise. You want to smoothly slide from a big dog "uhh" to a small dog "ehh" as your larynx slides upward. Again, place a finger or two lightly on your throat to feel your larynx move up and down.

**Your homework is** to practice the whisper siren for few minutes whenever you remember, throughout the day - say, whenever you go to the bathroom. It's almost silent, so you can do it anywhere and practice holding your muscles in place at the top (the high end of the siren, or the small dog) to build strength. Eventually, you want to learn to lift your larynx easily, without straining the muscles in your jaw and neck. As you get more comfortable with it, try to relax your neck a little bit more each time, until you can do it without tension.

## 3\. Pitch

Keep doing the previous exercises every day, but when you're ready for something more, you can start working on your _pitch_, or how high or low your voice is. Pitch is just one of many elements, and not even the most important, but it's probably the most well-known difference between the average male and female voice.

In addition to pitch, there are several _registers_ that your voice will lock into at different points along your range, each with a different sound quality. Watch [this video](https://youtu.be/CYEsGuldIQY) to hear the differences between a _chest voice_ and a falsetto (and a _mix voice_, which is technically the same register as your chest voice, your _modal register_). Follow along with the warmups in [this video](https://youtu.be/9-1Padxsmio?t=281), and then try switching between the registers a few times, both singing and speaking.

Then download the Android app [Vocal Pitch Monitor](https://play.google.com/store/apps/details?id=com.tadaoyamaoka.vocalpitchmonitor&hl=en_US) (or [Vocal Pitch Monitor](https://apps.apple.com/us/app/vocal-pitch-monitor/id842218231) on iOS) and in the settings, change the _Scale_ to _F Major_ and check the box to _Display frequency in Hz_. With the app running, talk in your starting voice and see where your pitch falls, naturally. A typical male speaking voice will stay between F2 and F3 (which are marked by horizontal lines, since we set the Scale to F Major). Now try talking higher and higher in pitch, until your voice is in the female range, around F3 and above. Don't go higher than F4, though, or you'll sound like a cartoon character!

You might find that you start in your modal register when you're in the male range, but flip over into falsetto at some point in order to get into the female range. Or you might find that you have to strain and shout to get that high. If that happens, just go back down to the pitch where you can still speak comfortably in your modal register and don't worry about going higher for now.

**Your homework is** to set aside some time every day (say, half an hour) to warm up with the video above and then practice speaking in the female range (between F3 and F4) or as close as you can get without straining or going into a falsetto. You can just say random things that pop into your head, recite lines from memory, or read a book or reddit comments out loud, while keeping an eye on your pitch in Vocal Pitch Monitor.

It might sound terrible, but that's okay - the important thing is to get used to speaking in that range. Drink water throughout and take a break if you feel your voice getting strained or hoarse.

# Level 2 - Intermediate

## 4\. Resonance

Once you are comfortable with manipulating your larynx and your pitch, and you'd like an additional challenge, you can try doing them at the same time. That means, while you are trying to talk in the female range, you also raise your larynx to reduce your vocal tract length. Start by following along with the exercises in [this video](https://youtu.be/iTViDd0QPEI).

It will probably sound pretty bad at first, but that's fine! Your goal at this stage is not to sound feminine, but to keep your pitch between F3 and F4 (with Vocal Pitch Monitor) and keep your larynx raised while talking (which you can feel by holding a finger lightly to your throat).

Your voice should sound more buzzy and brassy, which you'd call a _bright resonance_ (or _bright timbre_), as opposed to the dark, hollow resonance of more masculine voices - and that's a good thing! Watch [this video](https://youtu.be/21ZfGPp-Ves) to hear a great demonstration of this effect - you want your voice to be in the upper-right quadrant of the diagram.

Then, on top of that, you want to learn to arch your _tongue_ up and push it forward to reduce the amount of space in your mouth where sound can resonate. To get the feeling, whisper "kee" (as in "key") and keep pushing the middle of your tongue up high for the "ee" - just below where it touches the roof of your mouth to make the "k" sound. Say it a few times, while keeping your tongue clenched, pushing it a little higher each time. This is the smallest space you can make inside your mouth, the bright extreme of your _oral resonance_, opposite a yawn.

That's great for saying an "ee" sound, but when feminizing the other vowels, your tongue will be lower than it is for the "ee" but still higher and more forward than it would be in your masculine voice. And you still want to feel a bit of tension in your tongue, that clench, throughout. Essentially, you want to talk with a small space at the front of your mouth. That makes it sound like you have a smaller mouth than you actually do, which makes you sound more feminine.

Gaining mastery over your tongue is one of the trickiest skills of voice feminization, but it's arguably one of the most important. Get started on it by practicing the exercises in [this video](https://youtu.be/yFot-l2iVHw). Then watch [this video](https://youtu.be/biZN6zcBpVo) and try some _sirens_ and _trills_ across your range while raising your larynx and tongue.

**Your homework is** to take your daily speaking practice, where you try to keep your pitch between F3 and F4, and spend at least half that time talking with your larynx raised as well, for a bright, buzzy sound. Then, as best you can, try to add in the tongue clench too, pushing it up and forward to brighten the sound even more. See how it sounds with your larynx raised or lowered, your tongue arched or relaxed, and your pitch high or low, as well as in a whisper.

This is likely to cause a lot of tension in the muscles of your neck and throat at first, so do trills and yawn every so often to help them relax again. You can even try lying on your back while practicing, to force your body to relax. And of course, sip water throughout your practice session and take a break when your voice gets too tired or hoarse.

Also, keep practicing your whisper sirens multiple times a day, but add a whispered "kee" at the end of each one to bring your tongue up. This will allow you to go even higher with the siren and make a really tiny dog sound! Again, hold those muscles in place at the top and really clench your tongue. At the same time, try to relax as much tension as you can in your jaw and neck while still holding the same shape.

## 5\. Open Quotient

Go ahead and breathe a sigh of relief, because it's time for something a little easier!

Feminine voices generally sound _softer_ and more _breathy_ than masculine voices. Marilyn Monroe is an iconic example of this, as you can hear in [this video](https://youtu.be/ikUjhv4iT58).

When you try to speak in the upper range of your modal register without going into a falsetto, the natural tendency is to strain to reach those higher notes, which makes your voice sound harder, not softer, and not particularly feminine. This is because you put a lot of _compression_ on your vocal folds (vocal cords), squeezing them together more tightly. You want to learn to use less compression for a softer sound, where your vocal folds stay open more ( _open quotient_) while vibrating. With high compression (closed quotient), adding breathiness will just result in a strained sound like Ash Ketchum from Pokemon, as in [this video](https://youtu.be/s-0DuYcWeBE).

To learn to control the compression in your voice, start by watching [this video](https://youtu.be/J9K74QEzntA?t=240) and trying the _"ah-ha"_ exercise and the _vowel slides_. Then download the Android app [Spectroid](https://play.google.com/store/apps/details?id=org.intoorbit.spectrum&hl=en_US) (or [Spectrogram Pro](https://apps.apple.com/us/app/spectrogram-pro-with-super-smooth-60hz-update/id415301721) on iOS), and in the audio settings, change the _Desired transform interval_ to _10 ms (100 Hz)_ and check the box to _Stay awake_ in the display settings.

With the app running, start by saying "ahh" for a few seconds in your normal speaking voice. In the scrolling display, you should see a bunch of bright yellow lines showing up against the purple and pink background noise. Then whisper "ahh" for a few seconds, just with your breath. You should see some faint pink smudges, but no yellow lines. Now, heave a big, breathy sigh while saying "ahh..." in a soft, relaxed voice. Ideally, you will see faint yellow lines melding into a background of pink smudges. This is what it looks like when your voice has a high open quotient. It's somewhere in between a normal voice and a whisper.

**Your homework is** to spend a few minutes before your other voice exercises, to slide between a whisper and your normal speaking voice. It's a good warmup! You can start with one long, whispered "ahh" that you gradually turn into a spoken "ahh" and then back to a whisper, just by changing the compression. Do this with the Spectroid app running, so you can see the change as well as hear it. For a bit more of a challenge, try smoothly changing from a whisper, to a soft voice, to a normal voice while speaking or reading out loud.

Of course, you can also play with this during your daily speaking practice. See if you can make your voice a little softer, or really breathy, or changing from one extreme to another while still maintaining the feminine aspects of pitch and resonance that you've been working on.

## 6\. Intonation

All right. It's time to start imitating some voices!

_Intonation_ is the rise and fall of pitch as you speak. Masculine voices tend to be very monotone, where the pitch changes very slightly and infrequently from word to word, and important words are spoken louder for emphasis. Feminine voices tend to vary a lot in pitch, across a wider range, and big pitch changes are used to draw attention to the important words. Oftentimes, every word is spoken at a different pitch than the one before, and sometimes the pitch will change multiple times within a single word!

The clearest example of this can be found in that great figurehead of exaggerated femininity, the Disney princess. Watch [this video](https://youtu.be/O5zntdPGd00?t=223) for a virtuosic vocal tour through a diversity of Disney princess voices, and try closing your eyes and listening to the rise and fall of pitch in each one. You can even pull out your Vocal Pitch Monitor app and watch the pitch rise and fall on the screen!

**Your homework is** to spend some time every day trying to talk like a Disney princess, in addition to all your other exercises. Listen to [this clip](https://soundcloud.com/princessvoiceover/about-princess-voice-over) with Vocal Pitch Monitor open, watching the pitch rise and fall, and pause every sentence to try parroting back what you just heard, with the same rise and fall in your pitch. Don't worry about sounding good, and don't worry about your larynx or resonance either. Just focus on the pitch, and go ahead and use your falsetto to go high if you can. It will sound fake and silly, and that's okay - enjoy it!

The only thing that you should try to do, other than match the pitch, is to _smile_ while you speak, stretching your _lips_ across your teeth, and make your mouth opening a little smaller, like you're saying "ooh" (just pretend you're a dainty princess). This will also brighten your resonance a tiny bit, and make your voice sound that much more feminine. Use this for your princess voice practice, but also for your resonance practice as well, tightening your lips in addition to raising your larynx and tongue.

If you get bored of using that clip or just want to find something in your own accent, feel free to practice with other example voices, like in [this video](https://youtu.be/G4pLz-_CImE). Or make up your own princess voice if you can - the sillier the better. Delight in the ridiculousness of it all, and just have fun with it!

## 7\. Articulation

Ready to refine your resonance with another round of voice impressions? Like, totally!

So far, you've been working to brighten the timbre of your voice by raising your larynx and tongue to shrink the size of your vocal tract. But that doesn't always translate into sounding more feminine. If you want to sound feminine, you're going to have to get really specific with the way your tongue moves inside your mouth, to hone your oral resonance. That is, you'll have to fine-tune the way you say all your vowels and consonants - your _articulation_.

Fortunately, there's a fun way to do this! To put it simply, you want to talk like a Valley girl. Watch [this video](https://youtu.be/XPv5vradEw8) to hear what a stereotypical Valley girl sounds like. Not only do they rival Disney princesses in terms of their extreme intonation, they also brighten their vowels to a much greater degree than you'll hear in any other American accent (and if you have a British accent, try imitating the brighter vowels of an Australian accent instead, as in [this video](https://youtu.be/mIBg-w6TNLE)).

Some vowels are naturally dark in resonance (like "uh") because your tongue is low and there is more space in your mouth. Some vowels are naturally bright (like "ee") because your tongue is high, leaving a small amount of space in the back of your mouth. What Valley girls do, and what you want to learn to do yourself, is to replace each vowel sound in your speech with a slightly brighter vowel. Your "oh" becomes "uh", your "uh" becomes "eh", your "eh" becomes "ih", your "ih" becomes "ee" and so on, as in [this video](https://youtu.be/dZKzuVfUv3E?t=62). These are called _vowel mods_.

For a Valley girl, "ummm..." becomes "emmm..." and "lah-eek, toh-duh-lee" becomes "lih-eek, teh-dih-lee" - try saying each one! Then see if you can say them with vowels that are in between the two extremes - that's the sweet spot. Whatever your accent, the key is to push your tongue up and forward and just use the front for articulation. It helps to close your _jaw_ so your teeth are almost touching, to make it impossible for your tongue to drop too low.

There are also _consonant mods_, because consonants can be brighter or darker too. Consonants interrupt the flow of air from your lungs, by temporarily blocking your vocal tract with your lips, tongue, or soft palate. A heavier, more intense interruption will generally come across as more masculine, while a lighter, more subtle articulation will come across as more feminine.

For example, if you explosively say "bah!" in disgust, it will sound more masculine. If you quickly say "bababababa" it will sound more feminine, especially if you tighten your lips together to minimize the movement. If you say "arr!" like a pirate, it will sound more masculine. If you stop your tongue halfway through saying that heavy "r" sound, it will sound more feminine, especially if you also raise the back of your tongue at the same time to shrink the space in your mouth. Watch [this video](https://youtu.be/lGHoIjPJ7nc?t=164) to hear the difference between a masculine and feminine "r" and "s" sound.

**Your homework is** to spend some time every day trying to talk like a Valley girl, in addition to all your other exercises! Start with Lumpy Space Princess in [this video](https://youtu.be/hnFcLGwgNSc?t=86). Pause after each line she says and try to repeat it with the same vowel mods - "to get it" becomes "teh get eht" in her accent. Then try it again with a whisper. Do the same with [this video](https://www.youtube.com/watch?v=fETaoJBhY9g), [this video](https://youtu.be/l2OhyLfrogI), and the Valley girl video above. Don't worry too much about pitch, but pay close attention to the sounds of each vowel and consonant.

When you start to feel comfortable with these vowel and consonant mods, try incorporating them into your other voice exercises as well. You don't have to go to such an extreme that you sound like a Valley girl, of course, but play around with them to see how they change the sound! At the same time, focus on clenching your tongue (like "key") to brighten each vowel and consonant as much as possible, while keeping your lips tight and your jaw almost closed to minimize the space inside.

## 8\. Vocal Twang

Now, if you want to be heard above a lot of background noise, without relying on the booming strength of a masculine voice, you'll need to add a piercing brightness that will give your voice more power and clarity while also making it more feminine at the same time.

The secret is a singing technique known as _vocal twang_. It sounds almost like nasal resonance, where the sound goes through your nose, but it's not. Instead, vocal twang is created by squeezing what's known as the _aryepiglottic sphincter_ (or _AES_), which is right at the top of your larynx, above the vocal folds. You can see and hear the difference dramatically in [this video](https://youtu.be/ERAFQic5A-4), showing the throat of a female singer as she first hums (nasal resonance), then sings normally, then sings with a very pronounced twang.

The best way to learn this is through imitation. Quack like a duck, cry like a newborn baby, or say "I AM A ROBOT" in your best robot voice. They may not be pretty, much less feminine, but all of these are great examples of vocal twang pushed to an extreme. And you want to learn the extreme and then dial it back from there - it's a lot easier that way. So take a moment to try a few quacks, to cry like a newborn, and talk like a robot. Then watch [this video](https://youtu.be/1BLVrYKmwvc) and follow along with the singing exercise at the end.

Next, open up the Spectroid app, and say "uhh" in a relaxed voice. Notice where the yellow lines appear on the scrolling spectrograph. Then try saying "quack" like a duck or "I AM A ROBOT" in a robot voice - something with a lot of vocal twang. If you've done it correctly, you'll see a bright yellow band of lines appear past the 1000 Hz mark. The more you constrict the AES, the brighter the yellow band will be and the more you'll hear a harsh edge to your sound. Watch [this video](https://youtu.be/xAvCrxaLRvI) for a great example of this, starting with a dark "uhh" and gradually raising the larynx, raising the tongue, and then adding the vocal twang for maximum brightness.

**Your homework is** to spend a few minutes every day practicing your vocal twang, perhaps right after your open quotient warmup. With Spectroid running, try to imitate the video and say "uhh" in a relaxed voice and then gradually slide into a harsh, twangy "ehh" like a duck quacking, and back down to a relaxed voice again. Watch the spectrograph and try to get that yellow band as bright as possible when you add the vocal twang. Then pinch your nose shut too, so you don't accidentally cheat by using nasal resonance instead of twang! You should be able to do this just as easily with your nose pinched shut - otherwise you'll end up sounding like Squidward, as in [this video](https://youtu.be/E5BzhG_sKUw?t=43).

Then try adding different degrees of twang to your speaking practice, to see how it feels and sounds. You could go all the way and sound like SpongeBob SquarePants, take it out completely like his friend Patrick, or add just a hint of it and sound, well, more feminine. See what you like!

Vocal twang is also really great for feminizing your singing, if you're into that. Skillful use of vocal twang can turn a weak falsetto into a powerful head voice, and increase your upper range by an octave or more. It's also the secret behind CeeLo Green's distinctive singing voice, combining a dark oral resonance with a lot of bright vocal twang and a bit of nasal resonance, as you can hear in [this video](https://youtu.be/bKxodgpyGec). If you start there and then brighten your oral resonance with a raised larynx and tongue, you can sound like a female singer. Seriously.

## 9\. Throat Closure

So far you've learned almost all of the little levers you can use to change the sound of your voice. But there's one (or two!) more to get familiar with, at the back of the throat. You want to learn to move your _soft palate_ and your _pharynx_ to shrink the space in your throat, just like you've used your tongue and lips to shrink the space in your mouth. The effect is subtle, but it can often make the difference between an authentically feminine voice and one that just sounds... off, somehow.

You can see a very brief overview of the technique in [this video](https://youtu.be/lGHoIjPJ7nc?t=68). But to make it easier, you'll want to start with just the soft palate. Look in a mirror and say "ahh" and then "ung" and watch how the back of your tongue comes up, while the very back of the roof of your mouth (the soft palate) comes down slightly to meet it. When they touch, the air is blocked off from your mouth and forced through your nose instead, creating a hypernasal sound. Try the exercises in [this video](https://youtu.be/phuaeXjWpSQ) to learn to control your soft palate, and by extension, your nasal resonance. Generally, you want to reduce this nasality for a more feminine sound.

The next thing you want to learn is how to constrict your pharynx, or close your _pharyngeal wall_. Doing this will bring in the sides of your throat just below the soft palate ( _oropharynx_), pushing your tonsils against the back of your tongue. How do you do it? Gargling. Say "ahh" while you tilt your head back and gargle, then tilt your head upright again and try to keep the sound going. Or say "ahh" from the top of a swallow-and-hold, or even a whisper siren. Eventually, you want to be able to say "ung" while sticking your tongue way out - the only way you can do that is to push in the walls of your oropharynx, because your soft palate can't reach the back of your tongue while it's stretched out of your mouth. If you talk at the same time, you will sound like Meatwad, as in [this video](https://youtu.be/8GjFmjBMizc?t=71).

If you start with a Meatwad voice, and you bring your pitch up into a falsetto with a fair amount of nasal resonance and vocal twang and a lot of open quotient, what do you get? You get an Elmo voice, as in [this video](https://youtu.be/l2ppLtHbag4?t=23s). The reduced space in the back of the mouth and throat is what gives Elmo's voice its child-like quality. Of course, if you take that Elmo voice and bring the pitch down while constricting your pharynx as much as possible, you get a Smeagol or Gollum voice, as in [this video](https://www.youtube.com/watch?v=64mWOoj68qo&t=252). For Smeagol, you want to constrict not only the oropharynx but also the _hypopharynx_, further down the throat, to create a dampened sound like a sob or an old man.

You don't have to take it that far, but if you add just a hint of oropharyngeal throat closure, you can make your voice sound younger and more feminine. This is most clearly demonstrated with a "loli" voice, as in [this video](https://youtu.be/pzgqke3uNxE). If you whisper with a feminine vocal posture and then squeeze in the back of your mouth and throat a little, you can sound like a cute anime girl. Try it!

**Your homework is** to spend some time every day trying to talk like Meatwad and the other characters, by playing with your soft palate and pharynx position. And be sure to try whispering too, especially for the loli voice. You can download the Android app [Echo](https://play.google.com/store/apps/details?id=uk.co.projectneon.echo&hl=en) (or [Voice Back](https://apps.apple.com/us/app/voice-back-sing-speak/id1071730240) on iOS) and use it to record and play back your character voices, to hear how they actually sound. Don't worry about whether they match a specific character exactly, just see what sort of funny voices you can make!

Then try adding a hint of throat closure to your speaking practice, to see if you can use it to sound more feminine. If you're feeling brave, you can even record and play back your feminine voice experiments to help guide your practice. Good luck!

These are also important elements for singing feminization, especially for a voice like Britney Spears, which combines a fair amount of oropharyngeal constriction with a very _hyponasal_ sound, as if from a stuffy nose. You can hear it exaggerated in [this video](https://youtu.be/je-UHCniqnk). Imitating that sound is a great way to learn to achieve throat closure while simultaneously eliminating nasal resonance.

## 10\. Exploration

Congratulations. You have learned to manipulate every single element involved in vocal feminization! Now for the fun part - you get to play around with all these knobs and dials on the control panel of your voice, and find the configuration that you like best. You get to _explore_ the possibility space of your voice!

A great way to do this is with a _mantra phrase_. The idea is to say the same phrase over and over again while tweaking different aspects of your voice, so you can easily compare the sound without thinking about what you're going to say. Watch [this video](https://youtu.be/XNPPSd3AVwM) for an overview of the concept and some great example phrases that you can use yourself.

Now, try one of my own mantra phrases, which I designed specifically to help you practice and get a feel for your brightest, most feminine sound:

_"Keep it cutesy!"_

Try saying it a few times in a feminine voice, then whisper it a few times. If you break it down and stretch it out, it sounds like "keee-p ihhh-t keee-yooo-tsss-seee!" Try it.

When you say "k" the top of your tongue presses against the roof of your mouth to block off the air, and when you say "ee" your tongue drops down to let the air through. Try whispering "kee" while keeping your tongue pushed up toward the "k" position, so it moves as little as possible to get to the "ee" instead of dropping down so much. That will create your brightest possible "ee" sound.

Try saying "keep" with that bright sound - your tongue should hardly move at all. Then try saying "cute" by starting with that "kee" sound and then pushing your tongue slightly down into a "yoo" sound. Whisper it first, and then say it, moving your tongue as little as possible, so the brightness of the "kee" carries into the "yoo" because your tongue is still pushing up toward that "k" position.

Then whisper "tsss" and try to move your tongue as little as possible from the "t" to the "s" sound. That will create a brighter, sharper "s" which will come across as more feminine. At the same time, keep pushing the back of your tongue up toward the "k" position to brighten it further. This applies to all your sibilants, by the way - "s", "z", "sh", "zh", "ch", "j" and so on! Then try whispering "see" - sliding from the "s" back to the brightest possible "ee" that you can make.

Now put it together. Say "cutesy" - stretch it out like "keee-yooo-tsss-seee" - first in a whisper and then spoken in a feminine voice. Say "keep" and for the "p" sound, really tighten your lips into a small but narrow opening, and keep them tight as you touch your lips together briefly for a subtle, unobtrusive "p" sound. This applies to all your labial consonants - "p", "b", "m", "w", "f", "v" and so on - and you want to keep your lips somewhat tight even for your other consonants and vowels, because it will make them brighter. So use the word "keep" as a reminder of the posture of your tongue and lips that will produce a bright, feminine oral resonance.

Whisper and then say the whole thing, at a pitch that is about as high as you can comfortably speak without going into your falsetto. "Keep it cutesy!" You can stretch out all the sounds to really get a feel for them and find that brightest position. As you say the vowels, practice pushing the brightness to a buzzy, brassy extreme, raising your larynx, pushing the back of your tongue up, and layering on the vocal twang to find that harsh edge. The only thing you want to avoid is nasal resonance. So also try saying it while pinching your nose shut - it should sound almost the same, whether you pinch your nose or not. Practicing this will help you access and lock in your brightest, _cutest_ vocal posture and pitch, just by saying the phrase!

Once you get comfortable with that, you can also try some of my other mantra phrases:

_"Keep calm and carry on."_

This mantra phrase is similar, but with some darker vowel sounds like "ahh" in "calm" which you can practice saying while still clenching your tongue up toward that initial "k" position. There are also "r" and "l" sounds to practice brightening, again, by pushing your tongue up at the same time. Practice whispering it, stretching it out, and saying it with the brightest sound you can make.

_"We're beautiful creatures."_

This is my favorite mantra phrase. It starts with a "w" to remind you to keep your lips small and tight, then an "ee" sound to remind you to keep your tongue up, then dips into an "r" sound to help you practice saying "r" without dropping your tongue. Then the "b" tests your lips again, and the "bee" to the "yoo" helps you practice keeping that "ee" position with your tongue even while saying the darker vowels. And there is a great diversity of consonants and vowels to practice throughout the rest of the phrase, but no nasal sounds, so you can easily test for nasal resonance by pinching your nose shut. Plus, it's true - and don't you forget it!

_"Breathe and smile, smile and breathe."_

This is another one of my favorite mantra phrases, both for its message and for its phonetic properties. It starts with a bright "ee" vowel for the first word, but has a number of more complex combinations of vowels and consonants that are helpful to practice. And it's a good reminder!

Positive psychology and neuroscience tell us that the easiest way to feel good is simply to smile - the neural connections that make you smile when you're happy also make you happier when you smile! And a slow, gentle, deep breath through your nose is the easiest way to calm down your nervous system. Whenever you say this mantra phrase, take a moment afterward to make a subtle, almost imperceptible smile with your lips and then slowly fill your lungs as you inhale through your nose, spreading that smile throughout your whole body. Savor the feeling of peace. Then gently let the breath go, exhaling through your nose as you slowly relax your smile. Do this whenever you remember, as many times as you want. It's free!

**Your homework is** to practice these mantra phrases, and any other mantra phrases you like, to lock in your most feminine voice before your regular speaking practice every day, after warming up. You can also say them throughout your practice as a reminder, or even throughout your day! Try whispering them, too - not only so you can stealthily practice even with other people around, but so you can focus on the resonance, without worrying about pitch! Ideally you want to get in the habit of whispering to yourself in different voices, whenever you can get away with it - this will really accelerate your progress.

Also, use these mantra phrases to experiment with different feminine voices, to see what you like - bringing the pitch higher or lower, adjusting your larynx and tongue position, using more or less open quotient, or vocal twang, or throat closure, and playing with different patterns of intonation and articulation. Record and play back each experiment with the Echo app, and see what sounds better to you and what doesn't. The goal is not perfection, it's exploration! Then try practicing those voices while speaking for longer amounts of time - reading out loud or just saying whatever comes into your head. And whenever you get discouraged or frustrated, take a moment to _smile and breathe!_

## 11\. Polishing

Once you feel comfortable playing with the many possibilities of your voice, you can start honing in on the feminine voice that you actually want! It's time to _polish_ your voice.

Remember that voice clip you chose in the beginning as the female voice you'd like to imitate? Hopefully you've been listening to it regularly this whole time, but if not, now is the time to start!

Find that clip and play back a sentence or two. Then use the Echo app to record yourself saying the same sentence. Listen to the reference clip and then your own recording, and without judging it as good or bad, try going through each element of your voice and noticing where it is similar or different. How does the pitch compare? The resonance? The intonation? And so on.

If an element is different, try playing around with it a few times and then record yourself again, doing your best to match the reference clip. Do that for each element. It's not going to be perfect in one pass, but it's the polishing process that counts. And of course, you don't have to sound exactly like your inspiration voice - it's just a beacon that can help you find your way to the voice you want. And this is just another exercise to practice.

Still, you might find that it's difficult to deconstruct the differences in a voice clip just by listening to it. But don't worry! It's a skill you can practice, just like anything else. And fortunately, there's a great way to practice it...

Every day, people post voice clips on [r/transvoice](/r/transvoice), looking for feedback. And you are going to train your ear by listening to those clips, analyzing them, and responding with your kind and honest feedback. When you are ready, you will join them by posting a clip of your own voice! But first, you will need to create an account on [reddit.com](https://reddit.com), if you haven't already. Do it now - it's free!

Then, go to [r/transvoice](/r/transvoice) and find a voice clip that someone has recently posted. First, listen to the clip and just think about pitch. Does it sound to you like the pitch is in the male range, or the female range, or somewhere in between? Open up Vocal Pitch Monitor and play the clip again, and see where the pitch actually falls. Then listen to the clip while just focusing on the resonance, the timbre of the voice. Does it sound hollow and masculine, or bright and feminine, or more ambiguously androgynous? You can watch [this video](https://youtu.be/21ZfGPp-Ves) for reference - where would you place the sound on the diagram?

Once you've established the pitch and resonance, you can listen again for the other elements of the voice. Listen for the intonation - the way the pitch rises and falls. Is it monotone or musical? Listen for open quotient - is the voice soft, or hard and strained? Listen for vocal twang - is there a bright, piercing edge to the sound? And is it too little or too much? How is the articulation? Does the resonance drop or sound fake on certain vowels or consonants? Is there too much nasal resonance? Would it sound better with a little pharyngeal constriction?

As you analyze the clip, make note of all your observations in a comment on the post. You don't have to say whether the voice sounds _good_ or _bad_ \- just describe what you hear, starting with pitch and resonance, and then any other details that you notice. If you're not sure about something, you don't have to say anything about it. Then, if the person who posted the clip is actively soliciting feedback on voice feminization, and there are one or two elements that you think they could work on next, share a link to this guide and tell them which sections they should check out. Don't worry about whether your feedback is perfect! Just be kind and honest, and the community as a whole will benefit.

**Your homework is** to find a new voice clip on [r/transvoice](/r/transvoice) every day (ideally one with no comments yet, or very few) and leave a comment on it with your analysis and suggestions. If you do this daily, not only will you develop a very discerning ear over time, you will also help the community thrive!

Also, spend some time every day listening to and imitating your female voice reference, along with all your other exercises. Use Echo to record and play back your attempts, and analyze them just like you analyze the clips on [r/transvoice](/r/transvoice). You may find that a voice that seems too exaggerated in your head actually sounds naturally feminine in a recording - and to other people. Be kind to yourself, and trust the process. Polishing takes time.

When you are ready to share a clip of your own voice with the world, create a free account on [clyp.it](https://clyp.it) and record yourself speaking at least a few sentences in your feminine voice, and perhaps a mantra phrase or two. If you're up for it, record the same thing in your starting voice as well, for comparison. Make sure to set the clip to _Public_, then post the link on [r/transvoice](/r/transvoice) and ask for feedback!

Regardless of what people say, the important thing is to craft a voice that _you_ are happy with. And you are the only one who gets to decide what that means for you.

## 12\. Performance

Eventually, there will come a time when you are pretty happy with your voice, and you want to be able to start using it in front of other people. It might not be perfect, but you feel compelled to tackle what may be the most challenging step of all: going from practice to _performance_.

There are two parts to this. One is learning to launch into your feminine voice whenever you choose, even when you haven't warmed up. And the other is getting over the performance anxiety of using your voice in front of other people - which is totally normal! You just have to take it one step at a time.

To start with, you want to train your brain to experience your feminine voice as the default, not the exception. One way to do this is by _bookending_ your day with your voice, by practicing a few mantra phrases in your feminine voice immediately after waking up, before using your voice for anything else, and then again as the last thing you do before going to sleep. The morning is often the hardest time to feminize your voice, so this will allow you to practice that worst-case scenario right away and prime the rest of your day with the voice you want. Also, whatever you practice just before sleeping will be given higher priority when your experiences are consolidated into long-term memory.

Then, take some time every day to practice _alternating_ between your masculine starting voice and your feminine voice. Read a book out loud and switch voices on every paragraph, or read reddit comment threads and use one voice for the original poster and another for the replies. If you tend to drift from your feminine voice into a more androgynous voice over time, you can also practice alternating between your feminine and androgynous voices to help differentiate them in your mind.

To make it easier to shift into your feminine voice, you can start with a mantra phrase to help you lock in the sound. This is something you can even do in front of other people, if you whisper it or practice a _stealth mantra phrase_, like "ummm, let's see..." or "ummm, so..." You can use the "ummm" to find the pitch, sliding upward until you reach the right range, and then use the "let's see..." or "so..." to find your resonance. Sneaky!

**Your homework is** to practice these exercises every day, in addition to any of the previous exercises that you still find helpful. Then, you want to slowly start pushing your comfort zone when it comes to performing your voice in front of other people.

First, find a supportive friend or two, and tell them that you'd like their help in practicing your voice. If you don't feel comfortable asking anyone you know, you can try finding an anonymous friend on the [TransVoice Discord](https://discord.gg/FAmXNEJ) or the [Scinguistics Discord](https://discord.gg/RjatswF). Tell them that you would like to be able to call them up and have a conversation in your feminine voice, without having to explain yourself, and without them commenting on whether your voice is good or bad. You just need them to listen and be patient with you.

Then, when you have warmed up by practicing your voice in private, call your friend and speak to them in your feminine voice. If all you can do is say a mantra phrase before lapsing into your starting voice, that's awesome! You've overcome the biggest hurdle. Next time you feel up for it, you can try speaking a little longer, whether you're just reading out loud, or having an entire conversation. And don't worry about whether your voice sounds perfect or not - you can work on that by yourself. Just focus on getting comfortable using your voice with another person.

Once you feel comfortable calling your friend from the middle of a practice session, start challenging yourself a little more. Try meeting up with your friend in person and then, with your backs turned to each other, say a mantra phrase in your feminine voice. Then try doing it while facing each other. Eventually, you can work your way up to having an entire conversation in person, not only in private, but in a public place like a restaurant!

Of course, when you are out in the real world, it's often difficult to be heard over all the background noise. The important thing is to use more vocal twang instead of straining, while keeping your voice soft with open quotient. You can practice this on your own by playing [this video](https://youtu.be/jAg6tyC9Xxc) and trying to speak over it.

As you get more confident, you can start using your feminine voice more and more throughout your life - even while coughing and laughing, as in [this video](https://youtu.be/_DP6KB5j2qQ) or [this video](https://youtu.be/IP-mRByleSc). Love yourself, and enjoy the journey!

~L
